@@ -16,7 +16,7 @@
 # This script will start the datastore server listening on an available socket
 serverpath=.;
 
-CLASSPATH=.:dstore_extra_server.jar:dstore_core.jar:dstore_miners.jar:clientserver.jar:cdtminer.jar:cdtmodel.jar:cdtparser.jar:org.eclipse.core.runtime_3.4.0.v20080512.jar:org.eclipse.equinox.common_3.4.0.v20080421-2006.jar:org.eclipse.core.filesystem_1.2.0.v20080604-1400.jar:stubs.jar:lrparser.jar:xlcparser.jar:net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar:$CLASSPATH;
+CLASSPATH=.:dstore_extra_server.jar:dstore_core.jar:dstore_miners.jar:clientserver.jar:cdtminer.jar:cdtmodel.jar:cdtparser.jar:org.eclipse.core.runtime_3.5.0.v20090525.jar:org.eclipse.equinox.common_3.5.0.v20090520-1800.jar:org.eclipse.core.filesystem_1.2.0.v20090507.jar:com.ibm.icu.base_4.0.1.v20090415.jar:stubs.jar:lrparser.jar:xlcparser.jar:net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar:$CLASSPATH;
 export serverpath CLASSPATH
 
 
